@@ -19,18 +19,16 @@
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
-
 #include "MDF_FC_common_genx.h"
 
-_GENX_MAIN_ void Y410_444DScale16_Buf_0_Rot_270(
+_GENX_MAIN_ void Y210_444DScale16_Buf_0_Rot_270(
     CURBE_INPUT_OUTPUT,
     GLOBAL_BUFFER_INPUT_OUTPUT)
 {
-#define Y410_SUPPORT
+
 #define BUFFER_0
 #define ROTATE_270
-#include "PA_DScale_Buf.h"
-#undef ROTATE_90
+#include "Y210_DScale_Buf.h"
 #undef ROTATE_270
-#undef Y410_SUPPORT
+#undef BUFFER_0
 }
\ No newline at end of file
